pub struct Measurements { /* private fields */ }Expand description
Stores data required for each Measures globally.
Implementations
Sourceimpl Measurements
impl Measurements
Sourcepub fn register<T: Measure>(&mut self, world: &mut World) -> MeasureId
pub fn register<T: Measure>(&mut self, world: &mut World) -> MeasureId
Registers a Measure, making it require a ContentSize.
Sourcepub unsafe fn get_measurers(
&mut self,
world: UnsafeWorldCell<'_>,
) -> impl Index<MeasureId, Output = dyn Measurer>
pub unsafe fn get_measurers( &mut self, world: UnsafeWorldCell<'_>, ) -> impl Index<MeasureId, Output = dyn Measurer>
Gets all the Measure data, fetching their system params to the given world.
Safety
worldmust be able to access any component and resources immutably, except for components that are private and inaccessible to implementors ofMeasure.- The drop glue of the returned container must run before trying to access resources and components mutably, or making structural ECS changes.
Sourcepub fn apply_measurers(&mut self, world: &mut World)
pub fn apply_measurers(&mut self, world: &mut World)
Calls SystemState::apply for each Measure data.