pub struct Ui {Show 24 fields
pub display: Display,
pub box_sizing: BoxSizing,
pub overflow_x: Overflow,
pub overflow_y: Overflow,
pub scrollbar_width: f32,
pub position: Position,
pub inset: UiBorder,
pub size: UiSize,
pub min_size: UiSize,
pub max_size: UiSize,
pub aspect_ratio: Option<f32>,
pub margin: UiBorder,
pub padding: UiBorder,
pub border: UiBorder,
pub flex_direction: FlexDirection,
pub flex_wrap: FlexWrap,
pub gap: UiSize,
pub align_content: AlignContent,
pub align_items: AlignItems,
pub justify_content: JustifyContent,
pub flex_basis: Val,
pub flex_grow: f32,
pub flex_shrink: f32,
pub align_self: AlignSelf,
}Expand description
A Ui node, complete with its styling information.
Fields
display: DisplayLayout strategy to be used when laying out this node.
box_sizing: BoxSizingDefines whether size styles apply to the content box or the border box of the node.
overflow_x: OverflowHow children overflowing their container should affect layout in the X axis.
overflow_y: OverflowHow children overflowing their container should affect layout in the Y axis.
scrollbar_width: f32How much space (in pixels) should be reserved for the scrollbars of Overflow::Scroll.
position: PositionDetermines what the inset value use as a base offset.
inset: UiBorderDetermines how the position of this element should be tweaked relative to the layout defined.
size: UiSizeSets the initial size of the node.
min_size: UiSizeControls the minimum size of the node.
max_size: UiSizeControls the maximum size of the node.
aspect_ratio: Option<f32>Sets the preferred aspect ratio for the node, calculated as width divided by height.
margin: UiBorderHow large the margin should be on each side.
padding: UiBorderHow large the padding should be on each side.
border: UiBorderHow large the border should be on each side.
flex_direction: FlexDirectionDefines which direction the main axis flows in.
flex_wrap: FlexWrapDefines wrapping behavior for when children nodes exhaust their available space.
gap: UiSizeDetermines ow large the gaps between nodes. in the container should be.
align_content: AlignContentDetermines how content contained within this node should be aligned in the cross/block axis.
align_items: AlignItemsDetermines how this node’s children should be aligned in the cross/block axis.
justify_content: JustifyContentDetermines how content contained within this node should be aligned in the main/inline axis.
flex_basis: ValSets the initial main axis size of the node.
flex_grow: f32The relative rate at which this node grows when it is expanding to fill space.
flex_shrink: f32The relative rate at which this node shrinks when it is contracting to fit into space.
align_self: AlignSelfDetermines how this node should be aligned in the cross/block axis, falling back to the
parent’s AlignItems if not set.
Implementations