pub struct ComputedUi {
pub order: u32,
pub size: Vec2,
pub content_size: Vec2,
pub scrollbar_size: Vec2,
pub border: Border,
pub padding: Border,
pub margin: Border,
/* private fields */
}Expand description
The computed layout values of a Ui node.
Fields
order: u32The relative ordering of the node.
Nodes with a higher order should be rendered on top of those with a lower order. This is effectively a topological sort of each tree.
size: Vec2The width and height of the node.
content_size: Vec2The width and height of the content inside the node. This may be larger than the size of the node in the case of overflowing content and is useful for computing a “scroll width/height” for scrollable nodes.
scrollbar_size: Vec2The size of the scrollbars in each dimension. If there is no scrollbar then the size will be zero.
border: BorderThe size of the borders of the node.
padding: BorderThe size of the padding of the node.
margin: BorderThe size of the margin of the node.